{   GNU Pascal Interface to SDL. 
    Copyright (C) 2002 by Eike Lange
    
    This unit is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This unit is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this unit; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Eike Lange, eike@gnu.de
    http://www.gnu-pascal.de/~contrib/eike/

    This unit was implemented using version 1.2.4 of libSDL. 
    Some header files and/or routines were not supported:
      Missing:
        SDL_audio.h, SDL_byteorder.h, SDL_cdrom.h, SDL_copying.h
        SDL_endian.h, SDL_error.h (partially missing)
        SDL_getenv.h, SDL_joystick.h
        SDL_main.h (noting to implement?)
        SDL_mouse.h (SDL_Cursor not implemented)
        SDL_mutex.h
        SDL_name.h (nothing to implement?)
        SDL_opengl.h (very long)
        SDL_quit.h (nothing to implement?)
        SDL_rwops.h
        SDL_syswm.h (if you implement, check TSdlSysWMEvent)
        SDL_types.h (partially missing)
        SDL_version.h (partially missing)
        SDL_video.h (SDL_VideoDriverName, SDL_ListModes, 
          SDL_UpdateRects, SDL_SetColors, SDL_SetPalette,
          SDL_LoadBMP_RW, SDL_LoadBMP, SDL_SaveBMP_RW, SDL_SaveBMP,
          YUV video surface overlay functions
          OpenGL support functions
          SDL_SoftStretch, SDL_AllocSurface, SDL_BlitSurface)
}

{$if __GPC_RELEASE__ < 20020225}
{$error This unit requires GPC release 20020225 or newer.}
{$endif}

unit SDL;

interface

type
  {@section unsorted types }
  SdlString = String (1024);
  PByteCard = ^ByteCard;
  
  SdlThread = Pointer;
  TSdlThreadFunction = ^function (arg: Pointer): Integer;
  PSdlCursor = Pointer;  {!! should be implemented }
  TSdlTimerCallback = ^function (Intervall: Cardinal): Cardinal;
  TSdlNewTimerCallback = ^function (Interval: Cardinal;
    Param: Pointer): Cardinal;
  PSdlTimerId = Pointer;
  TSdlKey = Integer;
  TSdlMod = Integer;
  TSdlKeysym = record
    ScanCode: ByteCard;
    Sym: TSdlKey;
    Modif: TSdlMod;  {!! Different Name}
    Unicode: ShortCard
  end;
  
  {@section types from SDL_events.h }
  PSdlEvent = ^TSdlEvent;
  
  TSdlActiveEvent = record
    aType,  {!! Different Name}
    Gain, State: ByteCard
  end;
  TSdlKeyboardEvent = record
    aType,  {!! Different Name}
    Which, State: ByteCard;
    Keysym: TSdlKeysym
  end;
  TSdlMouseMotionEvent = record
    aType,  {!! Different Name}
    Which, State: ByteCard;
    x, y, xRel, yRel: ShortCard
  end;
  TSdlMouseButtonEvent = record
    aType,  {!! Different Name}
    Which, Button, State: ByteCard;
    X, Y: ShortCard
  end;
  TSdlJoyAxisEvent = record
    aType,  {!! Different Name}
    Which, Axis: ByteCard;
    aValue: ShortInt  {!! Different Name}
  end;
  TSdlJoyBallEvent = record
    aType,  {!! Different Name}
    Which, Ball: ByteCard;
    xRel, yRel: ShortInt
  end;
  TSdlJoyHatEvent = record
    aType,  {!! Different Name}
    Which, Hat,
    aValue: ByteCard  {!! Different Name}
  end;
  TSdlJoyButtonEvent = record
    aType,  {!! Different Name}
    Which, Button, State: ByteCard
  end;
  TSdlResizeEvent = record
    aType: ByteCard;  {!! Different Name}
    W, H: Integer
  end;
  TSdlExposeEvent = record
    aType: ByteCard  {!! Different Name}
  end;
  TSdlQuitEvent = record
    aType: ByteCard  {!! Different Name}
  end;
  TSdlUserEvent = record
    aType: ByteCard;  {!! Different Name}
    Code: Integer;
    Data1, Data2: Pointer
  end;
  TSdlSysWMEvent = record
    aType: ByteCard;  {!! Different Name}
    Msg: Pointer      {@@ Should be ^SdlSysWMmsg, which is not implemented }
  end;
  TSdlEvent = record
    case Byte of
       0: (aType:   ByteCard);
       1: (active:  TSdlActiveEvent);
       2: (key:     TSdlKeyboardEvent);
       3: (motion:  TSdlMouseMotionEvent); 
       4: (button:  TSdlMouseButtonEvent);
       5: (jaxis:   TSdlJoyAxisEvent);
       6: (jball:   TSdlJoyBallEvent);
       7: (jhat:    TSdlJoyHatEvent);
       8: (jbutton: TSdlJoyButtonEvent);
       9: (resize:  TSdlResizeEvent);
      10: (expose:  TSdlExposeEvent);
      11: (quit:    TSdlQuitEvent);
      12: (user:    TSdlUserEvent);
      13: (syswm:   TSdlSysWMEvent)
  end;
  TSdlEventAction = Integer;
  TSdlEventFilter = ^function (const Event: PSdlEvent): Integer;

  {@section types from SDL_video.h }
  PSdlRect      = ^TSdlRect;
  PSdlPalette   = ^TSdlPalette;
  PSdlPixelFormat = ^TSdlPixelFormat;
  PSdlSurface   = Pointer;
  {^TSdlSurface;}
  PSdlVideoInfo = ^TSdlVideoInfo;
  
  TSdlRect = record
    x, y: ShortInt;
    w, h: ShortCard
  end;
  TSdlColor = record
    r, g, b, unused: ByteCard
  end;
  PColorArray = ^TColorArray;
  TColorArray = array [0..High (Integer) div SizeOf (TSdlColor)] of TSdlColor;
  TSdlPalette = record
    NColors: Integer;
    Colors: PColorArray
  end;
  TSdlPixelFormat = record
    Palette: PSdlPalette;
    BitsPerPixel, BytesPerPixel, RLoss, GLoss, BLoss, ALoss,
      RShift, GShift, BShift, AShift: ByteCard;
    RMAsk, GMask, BMask, AMask: Cardinal;
    ColorKey: Cardinal;
    Alpha: ByteCard
  end;
  TSdlSurface = record
    Flags: Cardinal;
    Format: PSdlPixelFormat;
    W, H: Integer;
    Pitch: ShortCard;
    Pixels: Pointer;
    Offset: Integer;
    HwData: Pointer;  {@@ something different? }
    ClipRect: TSdlRect;
    Unused1: Cardinal;
    Locked: Cardinal;
    Map: Pointer;  {@@ Something Different? }
    FormatVersion: Cardinal;
    RefCount: Integer
  end;

  { needed for TSdlVideoInfo, TSdlOverlay }
  TCard01 = Cardinal (1);
  TCard06 = Cardinal (6);
  TCard16 = Cardinal (16);
  TCard31 = Cardinal (31);
  TSdlVideoInfo = packed record
    HwAvailable, WmAvailable: TCard01;
    UnusedBits1: TCard06;
    UnusedBits2: TCard01;
    BlitHw, BlitHwCC, BlitHwA, BlitSw, BlitSwCC, BlitSwA, BlitFill: TCard01;
    UnusedBits3: TCard16;
    VideoMem: Cardinal;
    VFmt: PSdlPixelFormat
  end;
  TSdlOverlay = packed record
    Format: Cardinal;
    W, H, Planes: Integer;
    Pitches, Pixels: Pointer;  {@@ something different!! }
    HwFuncs, HwData: Pointer;  {@@ something different? }
    HwOverlay: TCard01;
    Unused: TCard31
  end;
  TSdlGLattr    = Integer;
  TSdlGrabMode  = Integer;
  TSdlBlit      = ^function (Src: PSdlSurface; SrcRect: PSdlRect;
                    Dst: PSdlSurface; DstRect: PSdlRect): Integer;

{ Please do not assign anything to these identifiers. They should
be treated as constants }
var
  {@section Consts from SDL.h }
  SdlInitTimer:       Integer;  asmname '_p_sdl_init_timer';        external;
  SdlInitAudio:       Integer;  asmname '_p_sdl_init_audio';        external;
  SdlInitVideo:       Integer;  asmname '_p_sdl_init_video';        external;
  SdlInitCdrom:       Integer;  asmname '_p_sdl_init_cdrom';        external;
  SdlInitJoystick:    Integer;  asmname '_p_sdl_init_joystick';     external;
  SdlInitNoparachute: Integer;  asmname '_p_sdl_init_noparachute';  external;
  SdlInitEventThread: Integer;  asmname '_p_sdl_init_eventthread';  external;
  SdlInitEverything:  Integer;  asmname '_p_sdl_init_everything';   external;

  {@section Consts from SDL_active.h }
  SdlAppMouseFocus:   Integer;  asmname '_p_sdl_appmousefocus'; external;
  SdlAppInputFocus:   Integer;  asmname '_p_sdl_appinputfocus'; external;
  SdlAppActive:       Integer;  asmname '_p_sdl_appactive';     external;

  {@section Consts from SDL_events.h }
  SdlNOEVENT:           Integer; asmname '_p_sdl_NOEVENT'; external;
  SdlACTIVEEVENT:       Integer; asmname '_p_sdl_ACTIVEEVENT'; external;
  SdlKEYDOWN:           Integer; asmname '_p_sdl_KEYDOWN'; external;
  SdlKEYUP:             Integer; asmname '_p_sdl_KEYUP'; external;
  SdlMOUSEMOTION:       Integer; asmname '_p_sdl_MOUSEMOTION'; external;
  SdlMOUSEBUTTONDOWN:   Integer; asmname '_p_sdl_MOUSEBUTTONDOWN'; external;
  SdlMOUSEBUTTONUP:     Integer; asmname '_p_sdl_MOUSEBUTTONUP'; external;
  SdlJOYAXISMOTION:     Integer; asmname '_p_sdl_JOYAXISMOTION'; external;
  SdlJOYBALLMOTION:     Integer; asmname '_p_sdl_JOYBALLMOTION'; external;
  SdlJOYHATMOTION:      Integer; asmname '_p_sdl_JOYHATMOTION'; external;
  SdlJOYBUTTONDOWN:     Integer; asmname '_p_sdl_JOYBUTTONDOWN'; external;
  SdlJOYBUTTONUP:       Integer; asmname '_p_sdl_JOYBUTTONUP'; external;
  SdlQUITEvent:         Integer; asmname '_p_sdl_QUIT'; external;
  SdlSYSWMEVENT:        Integer; asmname '_p_sdl_SYSWMEVENT'; external;
  SdlEVENT_RESERVEDA:   Integer; asmname '_p_sdl_EVENT_RESERVEDA'; external;
  SdlEVENT_RESERVEDB:   Integer; asmname '_p_sdl_EVENT_RESERVEDB'; external;
  SdlVIDEORESIZE:       Integer; asmname '_p_sdl_VIDEORESIZE'; external;
  SdlVIDEOEXPOSE:       Integer; asmname '_p_sdl_VIDEOEXPOSE'; external;
  SdlEVENT_RESERVED2:   Integer; asmname '_p_sdl_EVENT_RESERVED2'; external;
  SdlEVENT_RESERVED3:   Integer; asmname '_p_sdl_EVENT_RESERVED3'; external;
  SdlEVENT_RESERVED4:   Integer; asmname '_p_sdl_EVENT_RESERVED4'; external;
  SdlEVENT_RESERVED5:   Integer; asmname '_p_sdl_EVENT_RESERVED5'; external;
  SdlEVENT_RESERVED6:   Integer; asmname '_p_sdl_EVENT_RESERVED6'; external;
  SdlEVENT_RESERVED7:   Integer; asmname '_p_sdl_EVENT_RESERVED7'; external;
  SdlUSEREVENT:         Integer; asmname '_p_sdl_USEREVENT'; external;
  SdlNUMEVENTS:         Integer; asmname '_p_sdl_NUMEVENTS'; external;

  SdlACTIVEEVENTMASK:     Integer; asmname '_p_sdl_ACTIVEEVENTMASK'; external;
  SdlKEYDOWNMASK:         Integer; asmname '_p_sdl_KEYDOWNMASK';  external;
  SdlKEYUPMASK:           Integer; asmname '_p_sdl_KEYUPMASK';    external;
  SdlMOUSEMOTIONMASK:     Integer; asmname '_p_sdl_MOUSEMOTIONMASK'; external;
  SdlMOUSEBUTTONDOWNMASK: Integer; asmname '_p_sdl_MOUSEBUTTONDOWNMASK'; external;
  SdlMOUSEBUTTONUPMASK:   Integer; asmname '_p_sdl_MOUSEBUTTONUPMASK'; external;
  SdlMOUSEEVENTMASK:      Integer; asmname '_p_sdl_MOUSEEVENTMASK'; external;
  SdlJOYAXISMOTIONMASK:   Integer; asmname '_p_sdl_JOYAXISMOTIONMASK'; external;
  SdlJOYBALLMOTIONMASK:   Integer; asmname '_p_sdl_JOYBALLMOTIONMASK'; external;
  SdlJOYHATMOTIONMASK:    Integer; asmname '_p_sdl_JOYHATMOTIONMASK'; external;
  SdlJOYBUTTONDOWNMASK:   Integer; asmname '_p_sdl_JOYBUTTONDOWNMASK'; external;
  SdlJOYBUTTONUPMASK:     Integer; asmname '_p_sdl_JOYBUTTONUPMASK'; external;
  SdlJOYEVENTMASK:        Integer; asmname '_p_sdl_JOYEVENTMASK'; external;
  SdlVIDEORESIZEMASK:     Integer; asmname '_p_sdl_VIDEORESIZEMASK'; external;
  SdlVIDEOEXPOSEMASK:     Integer; asmname '_p_sdl_VIDEOEXPOSEMASK'; external;
  SdlQUITMASK:            Integer; asmname '_p_sdl_QUITMASK';     external;
  SdlSYSWMEVENTMASK:      Integer; asmname '_p_sdl_SYSWMEVENTMASK'; external;
  SdlALLEVENTS:           Integer; asmname '_p_sdl_ALLEVENTS';    external;
  SdlQuery:       Integer; asmname '_p_sdl_query';    external;
  SdlIgnore:      Integer; asmname '_p_sdl_ignore';   external;
  SdlDisable:     Integer; asmname '_p_sdl_disable';  external;
  SdlEnable:      Integer; asmname '_p_sdl_enable';   external;

  { TSdlEventAction }
  SdlAddEvent:    Integer;  asmname '_p_sdl_addevent';  external;
  SdlPeekEvent:   Integer;  asmname '_p_sdl_peekevent'; external;
  SdlGetEvent:    Integer;  asmname '_p_sdl_getevent';  external;
  {@section Consts from SDL_keyboard.h }
  SdlAllHotkeys:            Integer; asmname '_p_sdl_all_hotkeys'; external;
  SdlDefaultRepeatDelay:    Integer; asmname '_p_sdl_default_repeat_delay'; external;
  SdlDefaultRepeatInterval: Integer; asmname '_p_sdl_default_repeat_interval'; external;

  {@section Const from SDL_keysym.h }
  { SDLKey consts }
  SdlkUNKNOWN:      Integer; asmname '_p_sdlk_UNKNOWN'; external;
  SdlkFIRST:        Integer; asmname '_p_sdlk_FIRST'; external;
  SdlkBACKSPACE:    Integer; asmname '_p_sdlk_BACKSPACE'; external;
  SdlkTAB:          Integer; asmname '_p_sdlk_TAB'; external;
  SdlkCLEAR:        Integer; asmname '_p_sdlk_CLEAR'; external;
  SdlkRETURN:       Integer; asmname '_p_sdlk_RETURN'; external;
  SdlkPAUSE:        Integer; asmname '_p_sdlk_PAUSE'; external;
  SdlkESCAPE:       Integer; asmname '_p_sdlk_ESCAPE'; external;
  SdlkSPACE:        Integer; asmname '_p_sdlk_SPACE'; external;
  SdlkEXCLAIM:      Integer; asmname '_p_sdlk_EXCLAIM'; external;
  SdlkQUOTEDBL:     Integer; asmname '_p_sdlk_QUOTEDBL'; external;
  SdlkHASH:         Integer; asmname '_p_sdlk_HASH'; external;
  SdlkDOLLAR:       Integer; asmname '_p_sdlk_DOLLAR'; external;
  SdlkAMPERSAND:    Integer; asmname '_p_sdlk_AMPERSAND'; external;
  SdlkQUOTE:        Integer; asmname '_p_sdlk_QUOTE'; external;
  SdlkLEFTPAREN:    Integer; asmname '_p_sdlk_LEFTPAREN'; external;
  SdlkRIGHTPAREN:   Integer; asmname '_p_sdlk_RIGHTPAREN'; external;
  SdlkASTERISK:     Integer; asmname '_p_sdlk_ASTERISK'; external;
  SdlkPLUS:         Integer; asmname '_p_sdlk_PLUS'; external;
  SdlkCOMMA:        Integer; asmname '_p_sdlk_COMMA'; external;
  SdlkMINUS:        Integer; asmname '_p_sdlk_MINUS'; external;
  SdlkPERIOD:       Integer; asmname '_p_sdlk_PERIOD'; external;
  SdlkSLASH:        Integer; asmname '_p_sdlk_SLASH'; external;
  Sdlk0:            Integer; asmname '_p_sdlk_0'; external;
  Sdlk1:            Integer; asmname '_p_sdlk_1'; external;
  Sdlk2:            Integer; asmname '_p_sdlk_2'; external;
  Sdlk3:            Integer; asmname '_p_sdlk_3'; external;
  Sdlk4:            Integer; asmname '_p_sdlk_4'; external;
  Sdlk5:            Integer; asmname '_p_sdlk_5'; external;
  Sdlk6:            Integer; asmname '_p_sdlk_6'; external;
  Sdlk7:            Integer; asmname '_p_sdlk_7'; external;
  Sdlk8:            Integer; asmname '_p_sdlk_8'; external;
  Sdlk9:            Integer; asmname '_p_sdlk_9'; external;
  SdlkCOLON:        Integer; asmname '_p_sdlk_COLON'; external;
  SdlkSEMICOLON:    Integer; asmname '_p_sdlk_SEMICOLON'; external;
  SdlkLESS:         Integer; asmname '_p_sdlk_LESS'; external;
  SdlkEQUALS:       Integer; asmname '_p_sdlk_EQUALS'; external;
  SdlkGREATER:      Integer; asmname '_p_sdlk_GREATER'; external;
  SdlkQUESTION:     Integer; asmname '_p_sdlk_QUESTION'; external;
  SdlkAT:           Integer; asmname '_p_sdlk_AT'; external;
  SdlkLEFTBRACKET:  Integer; asmname '_p_sdlk_LEFTBRACKET'; external;
  SdlkBACKSLASH:    Integer; asmname '_p_sdlk_BACKSLASH'; external;
  SdlkRIGHTBRACKET: Integer; asmname '_p_sdlk_RIGHTBRACKET'; external;
  SdlkCARET:        Integer; asmname '_p_sdlk_CARET'; external;
  SdlkUNDERSCORE:   Integer; asmname '_p_sdlk_UNDERSCORE'; external;
  SdlkBACKQUOTE:    Integer; asmname '_p_sdlk_BACKQUOTE'; external;
  Sdlka:            Integer; asmname '_p_sdlk_a'; external;
  Sdlkb:            Integer; asmname '_p_sdlk_b'; external;
  Sdlkc:            Integer; asmname '_p_sdlk_c'; external;
  Sdlkd:            Integer; asmname '_p_sdlk_d'; external;
  Sdlke:            Integer; asmname '_p_sdlk_e'; external;
  Sdlkf:            Integer; asmname '_p_sdlk_f'; external;
  Sdlkg:            Integer; asmname '_p_sdlk_g'; external;
  Sdlkh:            Integer; asmname '_p_sdlk_h'; external;
  Sdlki:            Integer; asmname '_p_sdlk_i'; external;
  Sdlkj:            Integer; asmname '_p_sdlk_j'; external;
  Sdlkk:            Integer; asmname '_p_sdlk_k'; external;
  Sdlkl:            Integer; asmname '_p_sdlk_l'; external;
  Sdlkm:            Integer; asmname '_p_sdlk_m'; external;
  Sdlkn:            Integer; asmname '_p_sdlk_n'; external;
  Sdlko:            Integer; asmname '_p_sdlk_o'; external;
  Sdlkp:            Integer; asmname '_p_sdlk_p'; external;
  Sdlkq:            Integer; asmname '_p_sdlk_q'; external;
  Sdlkr:            Integer; asmname '_p_sdlk_r'; external;
  Sdlks:            Integer; asmname '_p_sdlk_s'; external;
  Sdlkt:            Integer; asmname '_p_sdlk_t'; external;
  Sdlku:            Integer; asmname '_p_sdlk_u'; external;
  Sdlkv:            Integer; asmname '_p_sdlk_v'; external;
  Sdlkw:            Integer; asmname '_p_sdlk_w'; external;
  Sdlkx:            Integer; asmname '_p_sdlk_x'; external;
  Sdlky:            Integer; asmname '_p_sdlk_y'; external;
  Sdlkz:            Integer; asmname '_p_sdlk_z'; external;
  SdlkDELETE:       Integer; asmname '_p_sdlk_DELETE'; external;
  SdlkWORLD0:       Integer; asmname '_p_sdlk_WORLD_0'; external;
  SdlkWORLD1:       Integer; asmname '_p_sdlk_WORLD_1'; external;
  SdlkWORLD2:       Integer; asmname '_p_sdlk_WORLD_2'; external;
  SdlkWORLD3:       Integer; asmname '_p_sdlk_WORLD_3'; external;
  SdlkWORLD4:       Integer; asmname '_p_sdlk_WORLD_4'; external;
  SdlkWORLD5:       Integer; asmname '_p_sdlk_WORLD_5'; external;
  SdlkWORLD6:       Integer; asmname '_p_sdlk_WORLD_6'; external;
  SdlkWORLD7:       Integer; asmname '_p_sdlk_WORLD_7'; external;
  SdlkWORLD8:       Integer; asmname '_p_sdlk_WORLD_8'; external;
  SdlkWORLD9:       Integer; asmname '_p_sdlk_WORLD_9'; external;
  SdlkWORLD10:      Integer; asmname '_p_sdlk_WORLD_10'; external;
  SdlkWORLD11:      Integer; asmname '_p_sdlk_WORLD_11'; external;
  SdlkWORLD12:      Integer; asmname '_p_sdlk_WORLD_12'; external;
  SdlkWORLD13:      Integer; asmname '_p_sdlk_WORLD_13'; external;
  SdlkWORLD14:      Integer; asmname '_p_sdlk_WORLD_14'; external;
  SdlkWORLD15:      Integer; asmname '_p_sdlk_WORLD_15'; external;
  SdlkWORLD16:      Integer; asmname '_p_sdlk_WORLD_16'; external;
  SdlkWORLD17:      Integer; asmname '_p_sdlk_WORLD_17'; external;
  SdlkWORLD18:      Integer; asmname '_p_sdlk_WORLD_18'; external;
  SdlkWORLD19:      Integer; asmname '_p_sdlk_WORLD_19'; external;
  SdlkWORLD20:      Integer; asmname '_p_sdlk_WORLD_20'; external;
  SdlkWORLD21:      Integer; asmname '_p_sdlk_WORLD_21'; external;
  SdlkWORLD22:      Integer; asmname '_p_sdlk_WORLD_22'; external;
  SdlkWORLD23:      Integer; asmname '_p_sdlk_WORLD_23'; external;
  SdlkWORLD24:      Integer; asmname '_p_sdlk_WORLD_24'; external;
  SdlkWORLD25:      Integer; asmname '_p_sdlk_WORLD_25'; external;
  SdlkWORLD26:      Integer; asmname '_p_sdlk_WORLD_26'; external;
  SdlkWORLD27:      Integer; asmname '_p_sdlk_WORLD_27'; external;
  SdlkWORLD28:      Integer; asmname '_p_sdlk_WORLD_28'; external;
  SdlkWORLD29:      Integer; asmname '_p_sdlk_WORLD_29'; external;
  SdlkWORLD30:      Integer; asmname '_p_sdlk_WORLD_30'; external;
  SdlkWORLD31:      Integer; asmname '_p_sdlk_WORLD_31'; external;
  SdlkWORLD32:      Integer; asmname '_p_sdlk_WORLD_32'; external;
  SdlkWORLD33:      Integer; asmname '_p_sdlk_WORLD_33'; external;
  SdlkWORLD34:      Integer; asmname '_p_sdlk_WORLD_34'; external;
  SdlkWORLD35:      Integer; asmname '_p_sdlk_WORLD_35'; external;
  SdlkWORLD36:      Integer; asmname '_p_sdlk_WORLD_36'; external;
  SdlkWORLD37:      Integer; asmname '_p_sdlk_WORLD_37'; external;
  SdlkWORLD38:      Integer; asmname '_p_sdlk_WORLD_38'; external;
  SdlkWORLD39:      Integer; asmname '_p_sdlk_WORLD_39'; external;
  SdlkWORLD40:      Integer; asmname '_p_sdlk_WORLD_40'; external;
  SdlkWORLD41:      Integer; asmname '_p_sdlk_WORLD_41'; external;
  SdlkWORLD42:      Integer; asmname '_p_sdlk_WORLD_42'; external;
  SdlkWORLD43:      Integer; asmname '_p_sdlk_WORLD_43'; external;
  SdlkWORLD44:      Integer; asmname '_p_sdlk_WORLD_44'; external;
  SdlkWORLD45:      Integer; asmname '_p_sdlk_WORLD_45'; external;
  SdlkWORLD46:      Integer; asmname '_p_sdlk_WORLD_46'; external;
  SdlkWORLD47:      Integer; asmname '_p_sdlk_WORLD_47'; external;
  SdlkWORLD48:      Integer; asmname '_p_sdlk_WORLD_48'; external;
  SdlkWORLD49:      Integer; asmname '_p_sdlk_WORLD_49'; external;
  SdlkWORLD50:      Integer; asmname '_p_sdlk_WORLD_50'; external;
  SdlkWORLD51:      Integer; asmname '_p_sdlk_WORLD_51'; external;
  SdlkWORLD52:      Integer; asmname '_p_sdlk_WORLD_52'; external;
  SdlkWORLD53:      Integer; asmname '_p_sdlk_WORLD_53'; external;
  SdlkWORLD54:      Integer; asmname '_p_sdlk_WORLD_54'; external;
  SdlkWORLD55:      Integer; asmname '_p_sdlk_WORLD_55'; external;
  SdlkWORLD56:      Integer; asmname '_p_sdlk_WORLD_56'; external;
  SdlkWORLD57:      Integer; asmname '_p_sdlk_WORLD_57'; external;
  SdlkWORLD58:      Integer; asmname '_p_sdlk_WORLD_58'; external;
  SdlkWORLD59:      Integer; asmname '_p_sdlk_WORLD_59'; external;
  SdlkWORLD60:      Integer; asmname '_p_sdlk_WORLD_60'; external;
  SdlkWORLD61:      Integer; asmname '_p_sdlk_WORLD_61'; external;
  SdlkWORLD62:      Integer; asmname '_p_sdlk_WORLD_62'; external;
  SdlkWORLD63:      Integer; asmname '_p_sdlk_WORLD_63'; external;
  SdlkWORLD64:      Integer; asmname '_p_sdlk_WORLD_64'; external;
  SdlkWORLD65:      Integer; asmname '_p_sdlk_WORLD_65'; external;
  SdlkWORLD66:      Integer; asmname '_p_sdlk_WORLD_66'; external;
  SdlkWORLD67:      Integer; asmname '_p_sdlk_WORLD_67'; external;
  SdlkWORLD68:      Integer; asmname '_p_sdlk_WORLD_68'; external;
  SdlkWORLD69:      Integer; asmname '_p_sdlk_WORLD_69'; external;
  SdlkWORLD70:      Integer; asmname '_p_sdlk_WORLD_70'; external;
  SdlkWORLD71:      Integer; asmname '_p_sdlk_WORLD_71'; external;
  SdlkWORLD72:      Integer; asmname '_p_sdlk_WORLD_72'; external;
  SdlkWORLD73:      Integer; asmname '_p_sdlk_WORLD_73'; external;
  SdlkWORLD74:      Integer; asmname '_p_sdlk_WORLD_74'; external;
  SdlkWORLD75:      Integer; asmname '_p_sdlk_WORLD_75'; external;
  SdlkWORLD76:      Integer; asmname '_p_sdlk_WORLD_76'; external;
  SdlkWORLD77:      Integer; asmname '_p_sdlk_WORLD_77'; external;
  SdlkWORLD78:      Integer; asmname '_p_sdlk_WORLD_78'; external;
  SdlkWORLD79:      Integer; asmname '_p_sdlk_WORLD_79'; external;
  SdlkWORLD80:      Integer; asmname '_p_sdlk_WORLD_80'; external;
  SdlkWORLD81:      Integer; asmname '_p_sdlk_WORLD_81'; external;
  SdlkWORLD82:      Integer; asmname '_p_sdlk_WORLD_82'; external;
  SdlkWORLD83:      Integer; asmname '_p_sdlk_WORLD_83'; external;
  SdlkWORLD84:      Integer; asmname '_p_sdlk_WORLD_84'; external;
  SdlkWORLD85:      Integer; asmname '_p_sdlk_WORLD_85'; external;
  SdlkWORLD86:      Integer; asmname '_p_sdlk_WORLD_86'; external;
  SdlkWORLD87:      Integer; asmname '_p_sdlk_WORLD_87'; external;
  SdlkWORLD88:      Integer; asmname '_p_sdlk_WORLD_88'; external;
  SdlkWORLD89:      Integer; asmname '_p_sdlk_WORLD_89'; external;
  SdlkWORLD90:      Integer; asmname '_p_sdlk_WORLD_90'; external;
  SdlkWORLD91:      Integer; asmname '_p_sdlk_WORLD_91'; external;
  SdlkWORLD92:      Integer; asmname '_p_sdlk_WORLD_92'; external;
  SdlkWORLD93:      Integer; asmname '_p_sdlk_WORLD_93'; external;
  SdlkWORLD94:      Integer; asmname '_p_sdlk_WORLD_94'; external;
  SdlkWORLD95:      Integer; asmname '_p_sdlk_WORLD_95'; external;
  SdlkKP0:          Integer; asmname '_p_sdlk_KP0'; external;
  SdlkKP1:          Integer; asmname '_p_sdlk_KP1'; external;
  SdlkKP2:          Integer; asmname '_p_sdlk_KP2'; external;
  SdlkKP3:          Integer; asmname '_p_sdlk_KP3'; external;
  SdlkKP4:          Integer; asmname '_p_sdlk_KP4'; external;
  SdlkKP5:          Integer; asmname '_p_sdlk_KP5'; external;
  SdlkKP6:          Integer; asmname '_p_sdlk_KP6'; external;
  SdlkKP7:          Integer; asmname '_p_sdlk_KP7'; external;
  SdlkKP8:          Integer; asmname '_p_sdlk_KP8'; external;
  SdlkKP9:          Integer; asmname '_p_sdlk_KP9'; external;
  SdlkKPPERIOD:     Integer; asmname '_p_sdlk_KP_PERIOD'; external;
  SdlkKPDIVIDE:     Integer; asmname '_p_sdlk_KP_DIVIDE'; external;
  SdlkKPMULTIPL:    Integer; asmname '_p_sdlk_KP_MULTIPLY'; external;
  SdlkKPMINUS:      Integer; asmname '_p_sdlk_KP_MINUS'; external;
  SdlkKPPLUS:       Integer; asmname '_p_sdlk_KP_PLUS'; external;
  SdlkKPENTER:      Integer; asmname '_p_sdlk_KP_ENTER'; external;
  SdlkKPEQUALS:     Integer; asmname '_p_sdlk_KP_EQUALS'; external;
  SdlkUP:           Integer; asmname '_p_sdlk_UP'; external;
  SdlkDOWN:         Integer; asmname '_p_sdlk_DOWN'; external;
  SdlkRIGHT:        Integer; asmname '_p_sdlk_RIGHT'; external;
  SdlkLEFT:         Integer; asmname '_p_sdlk_LEFT'; external;
  SdlkINSERT:       Integer; asmname '_p_sdlk_INSERT'; external;
  SdlkHOME:         Integer; asmname '_p_sdlk_HOME'; external;
  SdlkEND:          Integer; asmname '_p_sdlk_END'; external;
  SdlkPAGEUP:       Integer; asmname '_p_sdlk_PAGEUP'; external;
  SdlkPAGEDOWN:     Integer; asmname '_p_sdlk_PAGEDOWN'; external;
  SdlkF1:           Integer; asmname '_p_sdlk_F1'; external;
  SdlkF2:           Integer; asmname '_p_sdlk_F2'; external;
  SdlkF3:           Integer; asmname '_p_sdlk_F3'; external;
  SdlkF4:           Integer; asmname '_p_sdlk_F4'; external;
  SdlkF5:           Integer; asmname '_p_sdlk_F5'; external;
  SdlkF6:           Integer; asmname '_p_sdlk_F6'; external;
  SdlkF7:           Integer; asmname '_p_sdlk_F7'; external;
  SdlkF8:           Integer; asmname '_p_sdlk_F8'; external;
  SdlkF9:           Integer; asmname '_p_sdlk_F9'; external;
  SdlkF10:          Integer; asmname '_p_sdlk_F10'; external;
  SdlkF11:          Integer; asmname '_p_sdlk_F11'; external;
  SdlkF12:          Integer; asmname '_p_sdlk_F12'; external;
  SdlkF13:          Integer; asmname '_p_sdlk_F13'; external;
  SdlkF14:          Integer; asmname '_p_sdlk_F14'; external;
  SdlkF15:          Integer; asmname '_p_sdlk_F15'; external;
  SdlkNUMLOCK:      Integer; asmname '_p_sdlk_NUMLOCK'; external;
  SdlkCAPSLOCK:     Integer; asmname '_p_sdlk_CAPSLOCK'; external;
  SdlkSCROLLOCK:    Integer; asmname '_p_sdlk_SCROLLOCK'; external;
  SdlkRSHIFT:       Integer; asmname '_p_sdlk_RSHIFT'; external;
  SdlkLSHIFT:       Integer; asmname '_p_sdlk_LSHIFT'; external;
  SdlkRCTRL:        Integer; asmname '_p_sdlk_RCTRL'; external;
  SdlkLCTRL:        Integer; asmname '_p_sdlk_LCTRL'; external;
  SdlkRALT:         Integer; asmname '_p_sdlk_RALT'; external;
  SdlkLALT:         Integer; asmname '_p_sdlk_LALT'; external;
  SdlkRMETA:        Integer; asmname '_p_sdlk_RMETA'; external;
  SdlkLMETA:        Integer; asmname '_p_sdlk_LMETA'; external;
  SdlkLSUPER:       Integer; asmname '_p_sdlk_LSUPER'; external;
  SdlkRSUPER:       Integer; asmname '_p_sdlk_RSUPER'; external;
  SdlkMODE:         Integer; asmname '_p_sdlk_MODE'; external;
  SdlkCOMPOSE:      Integer; asmname '_p_sdlk_COMPOSE'; external;
  SdlkHELP:         Integer; asmname '_p_sdlk_HELP'; external;
  SdlkPRINT:        Integer; asmname '_p_sdlk_PRINT'; external;
  SdlkSYSREQ:       Integer; asmname '_p_sdlk_SYSREQ'; external;
  SdlkBREAK:        Integer; asmname '_p_sdlk_BREAK'; external;
  SdlkMENU:         Integer; asmname '_p_sdlk_MENU'; external;
  SdlkPOWER:        Integer; asmname '_p_sdlk_POWER'; external;
  SdlkEURO:         Integer; asmname '_p_sdlk_EURO'; external;
  SdlkUNDO:         Integer; asmname '_p_sdlk_UNDO'; external;
  SdlkLAST:         Integer; asmname '_p_sdlk_LAST'; external;

  { SDLMod }
  KModNONE:       Integer; asmname '_p_kmod_NONE'; external;
  KModLSHIFT:     Integer; asmname '_p_kmod_LSHIFT'; external;
  KModRSHIFT:     Integer; asmname '_p_kmod_RSHIFT'; external;
  KModLCTRL:      Integer; asmname '_p_kmod_LCTRL'; external;
  KModRCTRL:      Integer; asmname '_p_kmod_RCTRL'; external;
  KModLALT:       Integer; asmname '_p_kmod_LALT'; external;
  KModRALT:       Integer; asmname '_p_kmod_RALT'; external;
  KModLMETA:      Integer; asmname '_p_kmod_LMETA'; external;
  KModRMETA:      Integer; asmname '_p_kmod_RMETA'; external;
  KModNUM:        Integer; asmname '_p_kmod_NUM'; external;
  KModCAPS:       Integer; asmname '_p_kmod_CAPS'; external;
  KModMODE:       Integer; asmname '_p_kmod_MODE'; external;
  KModRESERVED:   Integer; asmname '_p_kmod_RESERVED'; external;
  KModCTRL:       Integer; asmname '_p_kmod_CTRL'; external;
  KModSHIFT:      Integer; asmname '_p_kmod_SHIFT'; external;
  KModALT:        Integer; asmname '_p_kmod_ALT'; external;
  KModMETA:       Integer; asmname '_p_kmod_META'; external;



  {@section Consts from SDL_mouse.h }
  SdlButtonLeft:    Integer;    asmname '_p_sdl_button_left';	  external;
  SdlButtonMiddle:  Integer;    asmname '_p_sdl_button_middle';	external;
  SdlButtonRight:   Integer;    asmname '_p_sdl_button_right';	external;
  SdlButtonLMask:   Integer;    asmname '_p_sdl_button_lmask';	external;
  SdlButtonMMask:   Integer;    asmname '_p_sdl_button_mmask';	external;
  SdlButtonRMask:   Integer;    asmname '_p_sdl_button_rmask';	external;

  {@section Consts from SDL_timer.h }
  SdlTimeSlice:     Integer;  asmname '_p_sdl_timeslice';       external;
  TimerResolution:  Integer;  asmname '_p_timer_resolution';    external;

  {@section Consts from SDL_types.h }
  SdlPressed:       Integer;    asmname '_p_sdl_pressed';       external;
  SdlReleased:      Integer;    asmname '_p_sdl_released';      external;

  {@section Consts from SDL_version.h }
  SdlMajorVersion:  Integer;    asmname '_p_sdl_major_version'; external;
  SdlMinorVersion:  Integer;    asmname '_p_sdl_minor_version'; external;
  SdlPatchlevel:    Integer;    asmname '_p_sdl_patchlevel';    external;

  {@section Const from SDL_video.h }
  { Transparency definitions }
  SdlALPHAOPAQUE:       Integer; asmname '_p_sdl_ALPHA_OPAQUE'; external;
  SdlALPHATRANSPARENT:  Integer; asmname '_p_sdl_ALPHA_TRANSPARENT'; external;

  { flags for the SdlSurface 
    Available for SdlCreateRGBSurface or SdlSetVideoMode }
  SdlSWSURFACE:         Integer; asmname '_p_sdl_SWSURFACE'; external;
  SdlHWSURFACE:         Integer; asmname '_p_sdl_HWSURFACE'; external;
  SdlASYNCBLIT:         Integer; asmname '_p_sdl_ASYNCBLIT'; external;
  SdlANYFORMAT:         Integer; asmname '_p_sdl_ANYFORMAT'; external;
  SdlHWPALETTE:         Integer; asmname '_p_sdl_HWPALETTE'; external;
  SdlDOUBLEBUF:         Integer; asmname '_p_sdl_DOUBLEBUF'; external;
  SdlFULLSCREEN:        Integer; asmname '_p_sdl_FULLSCREEN'; external;
  SdlOPENGL:            Integer; asmname '_p_sdl_OPENGL'; external;
  SdlOPENGLBLIT:        Integer; asmname '_p_sdl_OPENGLBLIT'; external;
  SdlRESIZABLE:         Integer; asmname '_p_sdl_RESIZABLE'; external;
  SdlNOFRAME:           Integer; asmname '_p_sdl_NOFRAME'; external;
  SdlHWACCEL:           Integer; asmname '_p_sdl_HWACCEL'; external;
  SdlSRCCOLORKEY:       Integer; asmname '_p_sdl_SRCCOLORKEY'; external;
  SdlRLEACCELOK:        Integer; asmname '_p_sdl_RLEACCELOK'; external;
  SdlRLEACCEL:          Integer; asmname '_p_sdl_RLEACCEL'; external;
  SdlSRCALPHA:          Integer; asmname '_p_sdl_SRCALPHA'; external;
  SdlPREALLOC:          Integer; asmname '_p_sdl_PREALLOC'; external;

  { The most common video overlay formats }
  SdlYV12OVERLAY:       Integer; asmname '_p_sdl_YV12_OVERLAY'; external;
  SdlIYUVOVERLAY:       Integer; asmname '_p_sdl_IYUV_OVERLAY'; external;
  SdlYUY2OVERLAY:       Integer; asmname '_p_sdl_YUY2_OVERLAY'; external;
  SdlUYVYOVERLAY:       Integer; asmname '_p_sdl_UYVY_OVERLAY'; external;
  SdlYVYUOVERLAY:       Integer; asmname '_p_sdl_YVYU_OVERLAY'; external;

  { Flags for SdlPalette }
  SdlLOGPAL:            Integer; asmname '_p_sdl_LOGPAL'; external;
  SdlPHYSPAL:           Integer; asmname '_p_sdl_PHYSPAL'; external;

  { TSdlGlAttr }
  SdlGlRedSize:         Integer; asmname '_p_sdl_gl_RED_SIZE'; external;
  SdlGlGreenSize:       Integer; asmname '_p_sdl_gl_GREEN_SIZE'; external;
  SdlGlBlueSize:        Integer; asmname '_p_sdl_gl_BLUE_SIZE'; external;
  SdlGlALPHASize:       Integer; asmname '_p_sdl_gl_ALPHA_SIZE'; external;
  SdlGlBUFFERSize:      Integer; asmname '_p_sdl_gl_BUFFER_SIZE'; external;
  SdlGlDOUBLEBuffer:    Integer; asmname '_p_sdl_gl_DOUBLEBUFFER'; external;
  SdlGlDEPTHSize:       Integer; asmname '_p_sdl_gl_DEPTH_SIZE'; external;
  SdlGlSTENCILSize:     Integer; asmname '_p_sdl_gl_STENCIL_SIZE'; external;
  SdlGlACCUMRedSize:    Integer; asmname '_p_sdl_gl_ACCUM_RED_SIZE'; external;
  SdlGlACCUMGreenSize:  Integer; asmname '_p_sdl_gl_ACCUM_GREEN_SIZE'; external;
  SdlGlACCUMBlueSize:   Integer; asmname '_p_sdl_gl_ACCUM_BLUE_SIZE'; external;
  SdlGlACCUMAlphaSize:  Integer; asmname '_p_sdl_gl_ACCUM_ALPHA_SIZE'; external;

  { TSdlGrabMode }
  SdlGrabQuery:       Integer; asmname '_p_sdl_grab_query'; external;
  SdlGrabOff:         Integer; asmname '_p_sdl_grab_off'; external;
  SdlGrabOn:          Integer; asmname '_p_sdl_grab_on'; external;
  SdlGrabFullscreen:  Integer; asmname '_p_sdl_grab_fullscreen'; external;

{@section Routines from SDL.h }
function SdlInit (Flags: Cardinal): Integer; asmname 'SDL_Init';
function SdlInitSubsystem (Flags: Cardinal): Integer; asmname 'SDL_InitSubSystem';
procedure SdlQuitSubSystem (Flags: Cardinal); asmname 'SDL_QuitSubSystem';
function SdlWasInit (Flags: Cardinal): Cardinal; asmname 'SDL_WasInit';
procedure SdlQuit; asmname 'SDL_Quit';

{@section Routines from SDL_active.h }
function SdlGetAppState: ByteCard; asmname 'SDL_GetAppState';

{@section Routines from SDL_error.h }
function SdlGetError: SdlString;
procedure SdlClearError; asmname 'SDL_ClearError';

{@section routines from SDL_events.h }
function SdlEventMask (X: Integer): Integer; asmname '_p_sdl_eventmask';
procedure SdlPumpEvents; asmname 'SDL_PumpEvents';
{@@ Events should be an Array of size NumEvents }
function SdlPeepEvents (Events: PSdlEvent; NumEvents: Integer;
  Action: TSdlEventAction; Mask: Cardinal): Integer; asmname 'SDL_PeepEvents';
  
function SdlPollEvent (var Event: TSdlEvent): Boolean;
function SdlWaitEvent (var Event: PSdlEvent): Integer; asmname 'SDL_WaitEvent';
function SdlPushEvent (Event: PSdlEvent): Integer; asmname 'SDL_PushEvent';
procedure SdlSetEventFilter (Filter: TSdlEventFilter); asmname 'SDL_SetEventFilter';
function SdlGetEventFilter: TSdlEventFilter; asmname 'SDL_GetEventFilter';
function SdlEventState (aType: ByteCard; State: Integer): ByteCard;
  asmname 'SDL_EventState';

{@section Routines from SDL_keyboard.h }
type
  PKeyStateArray = ^TKeyStateArray;
  TKeyStateArray = array [0..High (Integer)] of ByteCard;

function SdlEnableUnicode (Enable: Integer): Integer; asmname 'SDL_EnableUNICODE';
function SdlEnableKeyRepeat (Delay, Interval: Integer): Integer;
  asmname 'SDL_EnableKeyRepeat';
function SdlGetKeystate (var NumKeys: Integer): PKeyStateArray; asmname 'SDL_GetKeyState';
function SdlGetModstate: TSdlMod; asmname 'SDL_GetModState';
procedure SdlSetModstate (ModState: TSdlMod);
function SdlGetKeyname (aKey: TSdlKey): SdlString;

{@section Routines from SDL_mouse.h }
function SdlGetMouseState (var x, y): ByteCard; asmname 'SDL_GetMouseState';
function SdlGetRelativeMouseState (var x, y): ByteCard; asmname 'SDL_GetRelativeMouseState';
procedure SdlWarpMouse (x, y: ShortCard); asmname 'SDL_WarpMouse';
function SdlCreateCursor (var Data, Mask: ByteCard;
  Width, Height, HotX, HotY: Integer): PSdlCursor; asmname 'SDL_CreateCursor';
procedure SdlSetCursor (Cursor: PSdlCursor); asmname 'SDL_SetCursor';
function SdlGetCursor: PSdlCursor; asmname 'SDL_GetCursor';
procedure SdlFreeCursor (Cursor: PSdlCursor); asmname 'SDL_FreeCursor';
function SdlShowCursor (Toggle: Integer): Integer; asmname 'SDL_ShowCursor';
function SdlButton (X: ByteCard): ByteCard; asmname '_p_sdl_button';

{@section Routines From SDL_timer.h }
function SdlGetTicks: Cardinal; asmname 'SDL_GetTicks';
procedure SdlDelay (ms: Cardinal); asmname 'SDL_Delay';
function SdlSetTimer (Interval: Cardinal; CB: TSdlTimerCallback): Integer;
  asmname 'SDL_SetTimer';
function SDL_AddTimer (Interval: Cardinal; Callback: TSdlNewTimerCallback;
  Param: Pointer): PSdlTimerId; asmname 'SDL_AddTimer';
function SdlRemoveTimer (T: PSdlTimerId): Boolean;

{@section Routines From SDL_thread.h }
function SdlCreateThread (fn: TSdlThreadFunction; Data: Pointer): SdlThread;
  asmname 'SDL_CreateThread';
function SdlThreadId: Cardinal; asmname 'SDL_ThreadID';
function SdlGetThreadId (thread: SdlThread): Cardinal; asmname 'SDL_GetThreadID';
procedure SdlWaitThread (thread: SdlThread; var Status: Integer); asmname 'SDL_WaitThread';
procedure SdlKillThread (thread: SdlThread); asmname 'SDL_KillThread';

{@section Routines From SDL_video.h }
function SdlVideoInit (DriverName: PChar; Flags: Cardinal): Integer;
  asmname 'SDL_VideoInit';
procedure SdlVideoQuit; asmname 'SDL_VideoQuit';
function SdlGetVideoSurface: PSdlSurface; asmname 'SDL_GetVideoSurface';
function SdlGetVideoInfo: PSdlVideoInfo; asmname 'SDL_GetVideoInfo';
function SdlVideoModeOk (Width, Height, Bpp: Integer;
  Flags: Cardinal): Integer; asmname 'SDL_VideoModeOK';
function SdlSetVideoMode (Width, Height, Bpp: Integer;
  Flags: Cardinal): PSdlSurface; asmname 'SDL_SetVideoMode';
procedure SdlUpdateRect (Surface: PSdlSurface; X, Y: MedInt;
  W, H: Cardinal); asmname 'SDL_UpdateRect';
function SdlFlip (Screen: PSdlSurface): Integer; asmname 'SDL_Flip';
function SdlSetGamma (Red, Green, Blue: ShortReal): Integer; asmname 'SDL_SetGamma';
function SdlSetGammaRamp (var Red, Green, Blue: ShortCard): Integer;
  asmname 'SDL_SetGammaRamp';
function SdlMapRGB (var Format: TSdlPixelFormat;
  R, G, B: ByteCard): Integer; asmname 'SDL_MapRGB';
function SdlMapRGBA (var Format: TSdlPixelFormat;
  R, G, B, A: ByteCard): Integer; asmname 'SDL_MapRGBA';
procedure SdlGetRGB (Pixel: Cardinal; Fmt: PSdlPixelFormat;
  var R, G, B: ByteCard); asmname 'SDL_GetRGB';
procedure SdlGetRGBA (Pixel: Cardinal; Fmt: PSdlPixelFormat;
  var R, G, B, A: ByteCard); asmname 'SDL_GetRGBA';
function SdlCreateRGBSurface (Flags: Cardinal; Width, Height, Depth: Integer;
  RMask, GMask, BMask, AMask: Cardinal): PSdlSurface;
  asmname 'SDL_CreateRGBSurface';
function SdlCreateRGBSurfaceFrom (Pixels: Pointer; Width, Height, Depth,
  Pitch: Integer; RMask, GMask, BMask, AMask: Cardinal): PSdlSurface;
  asmname 'SDL_CreateRGBSurfaceFrom';
procedure SdlFreeSurface (Surface: PSdlSurface); asmname 'SDL_FreeSurface';
function SdlLockSurface (Surface: PSdlSurface): Integer; asmname 'SDL_LockSurface';
procedure SdlUnlockSurface (Surface: PSdlSurface); asmname 'SDL_UnlockSurface';
function SdlSetColorKey (Surface: PSdlSurface; Flag, Key: Cardinal): Integer;
  asmname 'SDL_SetColorKey';
function SdlSetAlpha (Surface: PSdlSurface; Flag: Cardinal;
  Alpha: ByteCard): Integer; asmname 'SDL_SetAlpha';
function SdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Boolean;
procedure SdlGetClipRect (Surface: PSdlSurface; var Rect: TSdlRect);
  asmname 'SDL_GetClipRect';
function SdlConvertSurface (Surface: PSdlSurface; Fmt: PSdlPixelFormat;
  Flags: Cardinal): PSdlSurface; asmname 'SDL_ConvertSurface';
function SdlUpperBlit (SrcSurface: PSdlSurface; SrcRect: PSdlRect;
  DestSurface: PSdlSurface; DestRect: PSdlRect): Integer;
  asmname 'SDL_UpperBlit';
function SdlLowerBlit (SrcSurface: PSdlSurface; SrcRect: PSdlRect;
  DestSurface: PSdlSurface; DestRect: PSdlRect): Integer;
  asmname 'SDL_LowerBlit';
function SdlFillRect (Dst: PSdlSurface; DstRect: PSdlRect;
  Color: Cardinal): Integer; asmname 'SDL_FillRect';
function SdlDisplayFormat (Surface: PSdlSurface): Integer; asmname 'SDL_DisplayFormat';
function SdlDisplayFormatAlpha (Surface: PSdlSurface): PSdlSurface;
  asmname 'SDL_DisplayFormatAlpha';
procedure SdlWMSetCaption (TitleName, IconName: SdlString);
procedure SDLWMGetCaption (var TitleName, IconName: SdlString);
procedure SDLWMSetIcon (Surface: PSdlSurface; Mask: PByteCard);
  asmname 'SDL_WM_SetIcon';
function SdlWMIconifyWindow: Integer; asmname 'SDL_WM_IconifyWindow';
function SDLWMToggleFullScreen (Surface: PSdlSurface): Integer;
  asmname 'SDL_WM_ToggleFullScreen';
function SDLWMGrabInput (Mode: TSdlGrabMode): TSdlGrabMode;
  asmname 'SDL_WM_GrabInput';
function SdlMustlock (Surface: PSdlSurface): Boolean;


implementation

{$L sdlc.c}
{$L SDL}
{$L pthread}

function CSdlGetError: PChar; asmname 'SDL_GetError';
function SdlGetError: SdlString;
begin
  SdlGetError := CString2String (CSdlGetError)
end;

function CSdlPollEvent (var Event: TSdlEvent): Integer; asmname 'SDL_PollEvent';
function SdlPollEvent (var Event: TSdlEvent): Boolean;
var
  r: Integer;
begin
  r := CSdlPollEvent (Event);
  SdlPollEvent := (r = 1)  
end;


function CSdlRemoveTimer (T: PSdlTimerId): Integer; asmname 'SDL_RemoveTimer';
function SdlRemoveTimer (T: PSdlTimerId): Boolean;
begin
  SdlRemoveTimer := (CSdlRemoveTimer (T) = 1)
end;

function CSdlGetKeyname (aKey: TSdlKey): PChar; asmname 'SDL_GetKeyName';
function SdlGetKeyname (aKey: TSdlKey): SdlString;
begin
  SdlGetKeyname := CString2String (CSdlGetKeyname (aKey))
end;

function CSdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Integer;
asmname 'SDL_SetClipRect';
function SdlSetClipRect (Surface: PSdlSurface; const Rect: PSdlRect): Boolean;
begin
  SdlSetClipRect := (CSdlSetClipRect (Surface, Rect) = 1)
end;

procedure CSdlWMSetCaption (TitleName, IconName: PChar);
asmname 'SDL_WM_SetCaption';
procedure SdlWMSetCaption (TitleName, IconName: SdlString);
begin
  CSdlWMSetCaption (
    String2CString (TitleName),
    String2CString (IconName))
end;

procedure CSDLWMGetCaption (var TitleName, IconName: PChar);
asmname 'SDL_WM_GetCaption';
procedure SDLWMGetCaption (var TitleName, IconName: SdlString);
var
  t, i: PChar;
begin
  CSDLWMGetCaption (t, i);
  TitleName := CString2String (t);
  IconName := CString2String (i)
end;

function CSdlMustlock (Surface: PSdlSurface): Integer;
asmname '_p_sdl_mustlock';
function SdlMustlock (Surface: PSdlSurface): Boolean;
begin
  SdlMustlock := (CSdlMustlock (Surface) = 1)
end;

function CSizeofSdlKey: Integer; asmname '_p_sizeof_SDLKey';
function PSizeofSdlKey: Integer;
begin
  PSizeofSdlKey := SizeOf (TSdlKey)
end;

function CSizeofSdlMod: Integer; asmname '_p_sizeof_SDLMod';
function PSizeofSdlMod: Integer;
begin
  PSizeofSdlMod := SizeOf (TSdlMod)
end;

function CSizeofSdlKeysym: Integer; asmname '_p_sizeof_SDL_keysym';
function PSizeofSdlKeysym: Integer;
begin
  PSizeofSdlKeysym := SizeOf (TSdlKeysym)
end;

function CSizeofSdlActiveEvent: Integer; asmname '_p_sizeof_SDL_ActiveEvent';
function PSizeofSdlActiveEvent: Integer;
begin
  PSizeofSdlActiveEvent := SizeOf (TSdlActiveEvent)
end;

function CSizeofSdlKeyboardEvent: Integer; asmname '_p_sizeof_SDL_KeyboardEvent';
function PSizeofSdlKeyboardEvent: Integer;
begin
  PSizeofSdlKeyboardEvent := SizeOf (TSdlKeyboardEvent)
end;

function CSizeofSdlMouseMotionEvent: Integer; asmname '_p_sizeof_SDL_MouseMotionEvent';
function PSizeofSdlMouseMotionEvent: Integer;
begin
  PSizeofSdlMouseMotionEvent := SizeOf (TSdlMouseMotionEvent)
end;

function CSizeofSdlMouseButtonEvent: Integer; asmname '_p_sizeof_SDL_MouseButtonEvent';
function PSizeofSdlMouseButtonEvent: Integer;
begin
  PSizeofSdlMouseButtonEvent := SizeOf (TSdlMouseButtonEvent)
end;

function CSizeofSdlJoyAxisEvent: Integer; asmname '_p_sizeof_SDL_JoyAxisEvent';
function PSizeofSdlJoyAxisEvent: Integer;
begin
  PSizeofSdlJoyAxisEvent := SizeOf (TSdlJoyAxisEvent)
end;

function CSizeofSdlJoyBallEvent: Integer; asmname '_p_sizeof_SDL_JoyBallEvent';
function PSizeofSdlJoyBallEvent: Integer;
begin
  PSizeofSdlJoyBallEvent := SizeOf (TSdlJoyBallEvent)
end;

function CSizeofSdlJoyHatEvent: Integer; asmname '_p_sizeof_SDL_JoyHatEvent';
function PSizeofSdlJoyHatEvent: Integer;
begin
  PSizeofSdlJoyHatEvent := SizeOf (TSdlJoyHatEvent)
end;

function CSizeofSdlJoyButtonEvent: Integer; asmname '_p_sizeof_SDL_JoyButtonEvent';
function PSizeofSdlJoyButtonEvent: Integer;
begin
  PSizeofSdlJoyButtonEvent := SizeOf (TSdlJoyButtonEvent)
end;

function CSizeofSdlResizeEvent: Integer; asmname '_p_sizeof_SDL_ResizeEvent';
function PSizeofSdlResizeEvent: Integer;
begin
  PSizeofSdlResizeEvent := SizeOf (TSdlResizeEvent)
end;

function CSizeofSdlExposeEvent: Integer; asmname '_p_sizeof_SDL_ExposeEvent';
function PSizeofSdlExposeEvent: Integer;
begin
  PSizeofSdlExposeEvent := SizeOf (TSdlExposeEvent)
end;

function CSizeofSdlQuitEvent: Integer; asmname '_p_sizeof_SDL_QuitEvent';
function PSizeofSdlQuitEvent: Integer;
begin
  PSizeofSdlQuitEvent := SizeOf (TSdlQuitEvent)
end;

function CSizeofSdlUserEvent: Integer; asmname '_p_sizeof_SDL_UserEvent';
function PSizeofSdlUserEvent: Integer;
begin
  PSizeofSdlUserEvent := SizeOf (TSdlUserEvent)
end;

function CSizeofSdlSysWMEvent: Integer; asmname '_p_sizeof_SDL_SysWMEvent';
function PSizeofSdlSysWMEvent: Integer;
begin
  PSizeofSdlSysWMEvent := SizeOf (TSdlSysWMEvent)
end;

function CSizeofSdlEvent: Integer; asmname '_p_sizeof_SDL_Event';
function PSizeofSdlEvent: Integer;
begin
  PSizeofSdlEvent := SizeOf (TSdlEvent)
end;

function CSizeofSdlEventAction: Integer; asmname '_p_sizeof_SDL_eventaction';
function PSizeofSdlEventAction: Integer;
begin
  PSizeofSdlEventAction := SizeOf (TSdlEventAction)
end;

function CSizeofSdlRect: Integer; asmname '_p_sizeof_sdl_Rect';
function PSizeofSdlRect: Integer;
begin
  PSizeofSdlRect := SizeOf (TSdlRect)
end;

function CSizeofSdlColor: Integer; asmname '_p_sizeof_sdl_Color';
function PSizeofSdlColor: Integer;
begin
  PSizeofSdlColor := SizeOf (TSdlColor)
end;

function CSizeofSdlPalette: Integer; asmname '_p_sizeof_sdl_Palette';
function PSizeofSdlPalette: Integer;
begin
  PSizeofSdlPalette := SizeOf (TSdlPalette)
end;

function CSizeofSdlPixelFormat: Integer; asmname '_p_sizeof_sdl_PixelFormat';
function PSizeofSdlPixelFormat: Integer;
begin
  PSizeofSdlPixelFormat := SizeOf (TSdlPixelFormat)
end;

function CSizeofSdlSurface: Integer; asmname '_p_sizeof_sdl_Surface';
function PSizeofSdlSurface: Integer;
begin
  PSizeofSdlSurface := SizeOf (TSdlSurface)
end;

function CSizeofSdlVideoInfo: Integer; asmname '_p_sizeof_sdl_VideoInfo';
function PSizeofSdlVideoInfo: Integer;
begin
  PSizeofSdlVideoInfo := SizeOf (TSdlVideoInfo)
end;

function CSizeofSdlOverlay: Integer; asmname '_p_sizeof_sdl_Overlay';
function PSizeofSdlOverlay: Integer;
begin
  PSizeofSdlOverlay := SizeOf (TSdlOverlay)
end;

function CSizeofSdlGLattr: Integer; asmname '_p_sizeof_sdl_GLattr';
function PSizeofSdlGLattr: Integer;
begin
  PSizeofSdlGLattr := SizeOf (TSdlGLattr)
end;

function CSizeofSdlGrabMode: Integer; asmname '_p_sizeof_sdl_GrabMode';
function PSizeofSdlGrabMode: Integer;
begin
  PSizeofSdlGrabMode := SizeOf (TSdlGrabMode)
end;


to begin do
  begin
  if CSizeofSdlKey <> PSizeofSdlKey then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKey');
      Halt
    end;
  if CSizeofSdlMod <> PSizeofSdlMod then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMod');
      Halt
    end;
  if CSizeofSdlKeysym <> PSizeofSdlKeysym then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKeysym');
      Halt
    end;
  if CSizeofSdlActiveEvent <> PSizeofSdlActiveEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlActiveEvent');
      Halt
    end;
  if CSizeofSdlKeyboardEvent <> PSizeofSdlKeyboardEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlKeyboardEvent');
      Halt
    end;
  if CSizeofSdlMouseMotionEvent <> PSizeofSdlMouseMotionEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMouseMotionEvent');
      Halt
    end;
  if CSizeofSdlMouseButtonEvent <> PSizeofSdlMouseButtonEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlMouseButtonEvent');
      Halt
    end;
  if CSizeofSdlJoyAxisEvent <> PSizeofSdlJoyAxisEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyAxisEvent');
      Halt
    end;
  if CSizeofSdlJoyBallEvent <> PSizeofSdlJoyBallEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyBallEvent');
      Halt
    end;
  if CSizeofSdlJoyHatEvent <> PSizeofSdlJoyHatEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyHatEvent');
      Halt
    end;
  if CSizeofSdlJoyButtonEvent <> PSizeofSdlJoyButtonEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlJoyButtonEvent');
      Halt
    end;
  if CSizeofSdlResizeEvent <> PSizeofSdlResizeEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlResizeEvent');
      Halt
    end;
  if CSizeofSdlExposeEvent <> PSizeofSdlExposeEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlExposeEvent ');
      Halt
    end;
  if CSizeofSdlQuitEvent <> PSizeofSdlQuitEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlQuitEvent ');
      Halt
    end;
  if CSizeofSdlUserEvent <> PSizeofSdlUserEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlUserEvent ');
      Halt
    end;
  if CSizeofSdlSysWMEvent <> PSizeofSdlSysWMEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlSysWMEvent ');
      Halt
    end;
  if CSizeofSdlEvent <> PSizeofSdlEvent then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlEvent ');
      Halt
    end;
  if CSizeofSdlEventAction <> PSizeofSdlEventAction then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlEventAction');
      Halt
    end;
  if CSizeofSdlRect <> PSizeofSdlRect then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlRect');
      Halt
    end;
  if CSizeofSdlColor <> PSizeofSdlColor then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlColor');
      Halt
    end;
  if CSizeofSdlPalette <> PSizeofSdlPalette then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlPalette');
      Halt
    end;
  if CSizeofSdlPixelFormat <> PSizeofSdlPixelFormat then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlPixelFormat');
      Halt
    end;
  if CSizeofSdlSurface <> PSizeofSdlSurface then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlSurface');
      Halt
    end;
  if CSizeofSdlVideoInfo <> PSizeofSdlVideoInfo then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlVideoInfo');
      Halt
    end;
  if CSizeofSdlOverlay <> PSizeofSdlOverlay then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlOverlay');
      Halt
    end;
  if CSizeofSdlGLattr <> PSizeofSdlGLattr then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlGLattr');
      Halt
    end;
  if CSizeofSdlGrabMode <> PSizeofSdlGrabMode then
    begin
      WriteLn (StdErr, 'Size mismatch in SdlGrabMode');
      Halt
    end;

  end;

end.

